@@ -86,7 +86,7 @@
 #define KSERVICE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSERVICE_NO_DEPRECATED
-#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55300
+#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
 #endif
 #ifdef KSERVICE_NO_DEPRECATED_WARNINGS
 #  define KSERVICE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSERVICE_DEPRECATED_WARNINGS_SINCE KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x55300
+#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x55700
 #  endif
 #endif
 
@@ -187,6 +187,18 @@
 #else
 #  define KSERVICE_DEPRECATED_VERSION_5_83(text)
 #endif
+
+#if KSERVICE_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KSERVICE_DEPRECATED_VERSION_5_86(text) KSERVICE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KSERVICE_DEPRECATED_VERSION_5_86(text)
+#endif
+
+#if KSERVICE_DEPRECATED_WARNINGS_SINCE >= 0x55700
+#  define KSERVICE_DEPRECATED_VERSION_5_87(text) KSERVICE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KSERVICE_DEPRECATED_VERSION_5_87(text)
+#endif
 #define KSERVICE_DEPRECATED_VERSION_5(minor, text)      KSERVICE_DEPRECATED_VERSION_5_##minor(text)
 #define KSERVICE_DEPRECATED_VERSION(major, minor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KSERVICE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -252,7 +264,7 @@
 #define KSERVICE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSERVICE_NO_DEPRECATED
-#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55300
+#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
 #endif
 #ifdef KSERVICE_NO_DEPRECATED_WARNINGS
 #  define KSERVICE_DEPRECATED_WARNINGS_SINCE 0
@@ -262,7 +274,7 @@
 #  ifdef KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSERVICE_DEPRECATED_WARNINGS_SINCE KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x55300
+#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x55700
 #  endif
 #endif
 
@@ -353,6 +365,18 @@
 #else
 #  define KSERVICE_DEPRECATED_VERSION_5_83(text)
 #endif
+
+#if KSERVICE_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KSERVICE_DEPRECATED_VERSION_5_86(text) KSERVICE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KSERVICE_DEPRECATED_VERSION_5_86(text)
+#endif
+
+#if KSERVICE_DEPRECATED_WARNINGS_SINCE >= 0x55700
+#  define KSERVICE_DEPRECATED_VERSION_5_87(text) KSERVICE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KSERVICE_DEPRECATED_VERSION_5_87(text)
+#endif
 #define KSERVICE_DEPRECATED_VERSION_5(minor, text)      KSERVICE_DEPRECATED_VERSION_5_##minor(text)
 #define KSERVICE_DEPRECATED_VERSION(major, minor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KSERVICE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
